from distutils.core import setup

setup(
  name = 'nester__UeRS',
  version = '1.3.1',
  py_modules = ['nester__UeRS'],
  author = 'uendelrocha',
  author_email = 'uendelrocha@gmail.com',
  url = 'https://www.facebook.com/uendelrocha',
  description = 'Uma simples impressora de listas aninhadas',
  )
